@@ -1,4 +1,4 @@
-# copied from https://github.com/huggingface/diffusers/blame/44e56de9aaaa103ad11ca2953dc86ba6f64ba5d4/examples/community/lpw_stable_diffusion.py
+# copied and modified from https://github.com/huggingface/diffusers/blame/44e56de9aaaa103ad11ca2953dc86ba6f64ba5d4/examples/community/lpw_stable_diffusion.py
 
 import inspect
 import re
@@ -470,16 +470,6 @@ class StableDiffusionLongPromptWeightingPipeline(DiffusionPipeline):
             new_config["clip_sample"] = False
             scheduler._internal_dict = FrozenDict(new_config)
 
-        if safety_checker is None:
-            logger.warning(
-                f"You have disabled the safety checker for {self.__class__} by passing `safety_checker=None`. Ensure"
-                " that you abide to the conditions of the Stable Diffusion license and do not expose unfiltered"
-                " results in services or applications open to the public. Both the diffusers team and Hugging Face"
-                " strongly recommend to keep the safety filter enabled in all public facing circumstances, disabling"
-                " it only for use-cases that involve analyzing network behavior or auditing its results. For more"
-                " information, please have a look at https://github.com/huggingface/diffusers/pull/254 ."
-            )
-
         self.register_modules(
             vae=vae,
             text_encoder=text_encoder,
@@ -847,8 +837,10 @@ class StableDiffusionLongPromptWeightingPipeline(DiffusionPipeline):
 
         image = (image / 2 + 0.5).clamp(0, 1)
 
-        # we always cast to float32 as this does not cause significant overhead and is compatible with bfloa16
-        image = image.cpu().permute(0, 2, 3, 1).float().numpy()
+#        # we always cast to float32 as this does not cause significant overhead and is compatible with bfloa16
+#        image = image.cpu().permute(0, 2, 3, 1).float().numpy()
+
+        image = image.permute(0, 2, 3, 1) # XXX: modified by gtk_stable_diffusion project
 
         if self.safety_checker is not None:
             safety_checker_input = self.feature_extractor(self.numpy_to_pil(image), return_tensors="pt").to(
